@@ -86,10 +86,7 @@ api_opts = [
                 help=_('A comma separated list of dictionaries of the '
                        'enabled provider driver names and descriptions. '
                        'Must match the driver name in the '
-                       'octavia.api.drivers entrypoint. Example: '
-                       'amphora:The Octavia Amphora driver.,'
-                       'octavia:Deprecated alias of the Octavia '
-                       'Amphora driver.'),
+                       'octavia.api.drivers entrypoint.'),
                 default={'amphora': 'The Octavia Amphora driver.',
                          'octavia': 'Deprecated alias of the Octavia Amphora '
                          'driver.',
@@ -307,6 +304,11 @@ health_manager_opts = [
                help=_('Sleep time between health checks in seconds.')),
     cfg.IntOpt('sock_rlimit', default=0,
                help=_(' sets the value of the heartbeat recv buffer')),
+    cfg.IntOpt('failover_threshold', default=None,
+               help=_('Stop failovers if the count of simultaneously failed '
+                      'amphora reaches this number. This may prevent large '
+                      'scale accidental failover events, like in the case of '
+                      'network failures or read-only database issues.')),
 
     # Used by the health manager on the amphora
     cfg.ListOpt('controller_ip_port_list',
@@ -379,7 +381,7 @@ haproxy_amphora_opts = [
                       'seconds.')),
     cfg.StrOpt('haproxy_stick_size', default='10k',
                help=_('Size of the HAProxy stick table. Accepts k, m, g '
-                      'suffixes.  Example: 10k')),
+                      'suffixes.')),
     cfg.StrOpt('user_log_format',
                default='{{ project_id }} {{ lb_id }} %f %ci %cp %t %{+Q}r %ST '
                        '%B %U %[ssl_c_verify] %{+Q}[ssl_c_s_dn] %b %s %Tt '
@@ -473,6 +475,10 @@ controller_worker_opts = [
                default='',
                help=_('Optional SSH keypair name, in nova, that will be used '
                       'for the authorized_keys inside the amphora.')),
+    cfg.StrOpt('amp_timezone',
+               default='UTC',
+               help=_('The timezone to use in the Amphora as represented in '
+                      '/usr/share/zoneinfo.')),
     cfg.ListOpt('amp_boot_network_list',
                 default='',
                 help=_('List of networks to attach to the Amphorae. '
@@ -525,6 +531,7 @@ controller_worker_opts = [
                help=_('Number of times an amphora delete should be retried.')),
     cfg.IntOpt('amphora_delete_retry_interval', default=5,
                help=_('Time, in seconds, between amphora delete retries.')),
+    cfg.BoolOpt('event_notifications', default=True),
     # 2000 attempts is around 2h45 with the default settings
     cfg.IntOpt('db_commit_retry_attempts', default=2000,
                help=_('The number of times the database action will be '
@@ -542,10 +549,7 @@ task_flow_opts = [
     cfg.StrOpt('engine',
                default='parallel',
                choices=constants.SUPPORTED_TASKFLOW_ENGINE_TYPES,
-               help=_('TaskFlow engine to use. '
-                      'serial - Runs all tasks on a single thread. '
-                      'parallel - Schedules tasks onto different threads to '
-                      'allow for running non-dependent tasks simultaneously')),
+               help=_('TaskFlow engine to use.')),
     cfg.IntOpt('max_workers',
                default=5,
                help=_('The maximum number of workers')),
@@ -562,7 +566,11 @@ task_flow_opts = [
                 help=_('If True, enables TaskFlow jobboard.')),
     cfg.StrOpt('jobboard_backend_driver',
                default='redis_taskflow_driver',
-               choices=['redis_taskflow_driver', 'zookeeper_taskflow_driver'],
+               choices=[('redis_taskflow_driver',
+                         'Driver that will use Redis to store job states.'),
+                        ('zookeeper_taskflow_driver',
+                         'Driver that will use Zookeeper to store job states.')
+                        ],
                help='Jobboard backend driver that will monitor job state.'),
     cfg.ListOpt('jobboard_backend_hosts', default=['127.0.0.1'],
                 help='Jobboard backend server host(s).'),
