@@ -56,6 +56,11 @@ class CalculateAmphoraDelta(BaseNetworkTask):
     def execute(self, loadbalancer, amphora, availability_zone):
         LOG.debug("Calculating network delta for amphora id: %s", amphora.id)
 
+        vip_subnet_to_net_map = {
+            loadbalancer.vip.subnet_id:
+            loadbalancer.vip.network_id,
+        }
+
         # Figure out what networks we want
         # seed with lb network(s)
         if (availability_zone and
@@ -70,10 +75,12 @@ class CalculateAmphoraDelta(BaseNetworkTask):
         loadbalancer = self.lb_repo.get(
             db_apis.get_session(), id=loadbalancer.id)
 
-        desired_subnet_to_net_map = {
-            loadbalancer.vip.subnet_id:
-            loadbalancer.vip.network_id,
-        }
+        desired_subnet_to_net_map = {}
+        for mgmt_net_id in management_nets:
+            for subnet_id in self.network_driver.get_network(
+                    mgmt_net_id).subnets:
+                desired_subnet_to_net_map[subnet_id] = mgmt_net_id
+        desired_subnet_to_net_map.update(vip_subnet_to_net_map)
 
         for pool in loadbalancer.pools:
             for member in pool.members:
@@ -92,12 +99,7 @@ class CalculateAmphoraDelta(BaseNetworkTask):
         nics = self.network_driver.get_plugged_networks(
             amphora.compute_id)
         # we don't have two nics in the same network
-        # Don't include the nics connected to the management network, we don't
-        # want to update these interfaces.
-        network_to_nic_map = {
-            nic.network_id: nic
-            for nic in nics
-            if nic.network_id not in management_nets}
+        network_to_nic_map = {nic.network_id: nic for nic in nics}
 
         plugged_network_ids = set(network_to_nic_map)
 
@@ -588,7 +590,9 @@ class AllocateVIP(BaseNetworkTask):
                   loadbalancer.vip.subnet_id,
                   loadbalancer.vip.ip_address,
                   loadbalancer.id)
-        vip = self.network_driver.allocate_vip(loadbalancer)
+        # allocated_vips returns (vip, add_vips), skipping the 2nd element as
+        # amphorav1 doesn't support add_vips
+        vip = self.network_driver.allocate_vip(loadbalancer)[0]
         LOG.info("Allocated vip with port id %s, subnet id %s, ip address %s "
                  "for load balancer %s",
                  loadbalancer.vip.port_id,
