@@ -608,6 +608,7 @@ class TestAmphoraDriverTasks(base.TestCase):
                     'host_routes': []
                 },
                 constants.VRRP_PORT: mock.MagicMock(),
+                'additional_vip_data': []
             }
         }
         mock_amphora_repo_get.return_value = _db_amphora_mock
@@ -623,7 +624,8 @@ class TestAmphoraDriverTasks(base.TestCase):
 
         mock_driver.post_vip_plug.assert_called_once_with(
             _db_amphora_mock, _db_load_balancer_mock, amphorae_net_config_mock,
-            vip_subnet=vip_subnet, vrrp_port=vrrp_port)
+            vip_subnet=vip_subnet, vrrp_port=vrrp_port,
+            additional_vip_data=[])
 
         # Test revert
         amp = amphora_post_vip_plug_obj.revert(None, _amphora_mock, _LB_mock)
@@ -674,6 +676,7 @@ class TestAmphoraDriverTasks(base.TestCase):
                     'host_routes': host_routes
                 },
                 constants.VRRP_PORT: mock.MagicMock(),
+                'additional_vip_data': []
             }
         }
         mock_amphora_repo_get.return_value = _db_amphora_mock
@@ -689,7 +692,8 @@ class TestAmphoraDriverTasks(base.TestCase):
 
         mock_driver.post_vip_plug.assert_called_once_with(
             _db_amphora_mock, _db_load_balancer_mock, amphorae_net_config_mock,
-            vip_subnet=vip_subnet, vrrp_port=vrrp_port)
+            vip_subnet=vip_subnet, vrrp_port=vrrp_port,
+            additional_vip_data=[])
 
         call_kwargs = mock_driver.post_vip_plug.call_args[1]
         vip_subnet_arg = call_kwargs.get(constants.VIP_SUBNET)
@@ -703,6 +707,77 @@ class TestAmphoraDriverTasks(base.TestCase):
             amphorae_net_config_mock[AMP_ID][
                 constants.VIP_SUBNET]['host_routes'])
 
+    @mock.patch('octavia.db.repositories.LoadBalancerRepository.update')
+    @mock.patch('octavia.db.repositories.LoadBalancerRepository.get')
+    def test_amphora_post_vip_plug_with_additional_vips(
+            self, mock_lb_get, mock_loadbalancer_repo_update, mock_driver,
+            mock_generate_uuid, mock_log, mock_get_session,
+            mock_listener_repo_get, mock_listener_repo_update,
+            mock_amphora_repo_get, mock_amphora_repo_update):
+
+        host_routes = [{'destination': '10.0.0.0/16',
+                        'nexthop': '192.168.10.3'},
+                       {'destination': '10.2.0.0/16',
+                        'nexthop': '192.168.10.5'}]
+        additional_host_routes = [{'destination': '2001:db9::/64',
+                                   'nexthop': '2001:db8::1:fff'}]
+        amphorae_net_config_mock = {
+            AMP_ID: {
+                constants.VIP_SUBNET: {
+                    'host_routes': host_routes
+                },
+                constants.VRRP_PORT: mock.MagicMock(),
+                'additional_vip_data': [{
+                    'ip_address': '2001:db8::3',
+                    'subnet': {
+                        'host_routes': additional_host_routes
+                    }
+                }]
+            }
+        }
+        mock_amphora_repo_get.return_value = _db_amphora_mock
+        mock_lb_get.return_value = _db_load_balancer_mock
+        amphora_post_vip_plug_obj = amphora_driver_tasks.AmphoraPostVIPPlug()
+        amphora_post_vip_plug_obj.execute(_amphora_mock,
+                                          _LB_mock,
+                                          amphorae_net_config_mock)
+        vip_subnet = network_data_models.Subnet(
+            **amphorae_net_config_mock[AMP_ID]['vip_subnet'])
+        vrrp_port = network_data_models.Port(
+            **amphorae_net_config_mock[AMP_ID]['vrrp_port'])
+        additional_vip_data = [
+            network_data_models.AdditionalVipData(
+                ip_address=add_vip_data['ip_address'],
+                subnet=network_data_models.Subnet(
+                    host_routes=add_vip_data['subnet']['host_routes']))
+            for add_vip_data in amphorae_net_config_mock[
+                AMP_ID]['additional_vip_data']]
+
+        mock_driver.post_vip_plug.assert_called_once_with(
+            _db_amphora_mock, _db_load_balancer_mock, amphorae_net_config_mock,
+            vip_subnet=vip_subnet, vrrp_port=vrrp_port,
+            additional_vip_data=additional_vip_data)
+
+        call_kwargs = mock_driver.post_vip_plug.call_args[1]
+        vip_subnet_arg = call_kwargs.get(constants.VIP_SUBNET)
+        self.assertEqual(2, len(vip_subnet_arg.host_routes))
+        for hr1, hr2 in zip(host_routes, vip_subnet_arg.host_routes):
+            self.assertEqual(hr1['destination'], hr2.destination)
+            self.assertEqual(hr1['nexthop'], hr2.nexthop)
+
+        self.assertEqual(
+            host_routes,
+            amphorae_net_config_mock[AMP_ID][
+                constants.VIP_SUBNET]['host_routes'])
+
+        add_vip_data_arg = call_kwargs.get('additional_vip_data')
+        self.assertEqual(1, len(add_vip_data_arg[0].subnet.host_routes))
+        hr1 = add_vip_data_arg[0].subnet.host_routes[0]
+        self.assertEqual(
+            additional_host_routes[0]['destination'], hr1.destination)
+        self.assertEqual(
+            additional_host_routes[0]['nexthop'], hr1.nexthop)
+
     @mock.patch('octavia.db.repositories.LoadBalancerRepository.update')
     @mock.patch('octavia.db.repositories.LoadBalancerRepository.get')
     def test_amphorae_post_vip_plug(self, mock_lb_get,
@@ -730,7 +805,8 @@ class TestAmphoraDriverTasks(base.TestCase):
 
         mock_driver.post_vip_plug.assert_called_once_with(
             _db_amphora_mock, _db_load_balancer_mock, amphorae_net_config_mock,
-            vip_subnet=vip_subnet, vrrp_port=vrrp_port)
+            vip_subnet=vip_subnet, vrrp_port=vrrp_port,
+            additional_vip_data=[])
 
     def test_amphora_cert_upload(self,
                                  mock_driver,
